@@ -1,15 +1,11 @@
 package Database::Migrator::Pg;
-{
-  $Database::Migrator::Pg::VERSION = '0.04';
-}
-BEGIN {
-  $Database::Migrator::Pg::AUTHORITY = 'cpan:DROLSKY';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.05';
+
 use Database::Migrator 0.07;
 use Database::Migrator::Types qw( HashRef Str );
 use File::Slurp qw( read_file );
@@ -22,17 +18,15 @@ use Moose;
 
 with 'Database::Migrator::Core';
 
-has encoding => (
-    is        => 'ro',
-    isa       => Str,
-    predicate => '_has_encoding',
-);
+for my $create_flag (
+    qw( encoding locale lc_collate lc_ctype owner tablespace template )) {
 
-has owner => (
-    is        => 'ro',
-    isa       => Str,
-    predicate => '_has_owner',
-);
+    has $create_flag => (
+        is        => 'ro',
+        isa       => Str,
+        predicate => '_has_' . $create_flag,
+    );
+}
 
 has _psql => (
     is       => 'ro',
@@ -50,6 +44,7 @@ has _cli_constructor_args => (
     builder  => '_build_cli_constructor_args',
 );
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _create_database {
     my $self = shift;
 
@@ -58,10 +53,20 @@ sub _create_database {
     $self->logger()->info("Creating the $database database");
 
     my @opts;
-    push @opts, '-E', $self->encoding()
+    push @opts, '--encoding', $self->encoding()
         if $self->_has_encoding();
-    push @opts, '-O', $self->owner()
+    push @opts, '--locale', $self->locale()
+        if $self->_has_locale();
+    push @opts, '--lc-collate', $self->lc_collate()
+        if $self->_has_lc_collate();
+    push @opts, '--lc-ctype', $self->lc_ctype()
+        if $self->_has_lc_ctype();
+    push @opts, '--owner', $self->owner()
         if $self->_has_owner();
+    push @opts, '--tablespace', $self->tablespace()
+        if $self->_has_tablespace();
+    push @opts, '--template', $self->template()
+        if $self->_has_template();
 
     $self->_run_cli_or_die(
         'createdb',
@@ -136,6 +141,7 @@ sub _dropdb {
 
     return Pg::CLI::dropdb->new( $self->_cli_constructor_args() );
 }
+## use critic
 
 sub _build_psql {
     my $self = shift;
@@ -169,7 +175,9 @@ around _build_dbh => sub {
     return $dbh;
 };
 
-sub _driver_name { 'Pg' }
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
+sub _driver_name {'Pg'}
+## use critic
 
 __PACKAGE__->meta()->make_immutable();
 
@@ -187,7 +195,7 @@ Database::Migrator::Pg - Database::Migrator implementation for Postgres
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -210,29 +218,59 @@ L<Database::Migrator> and L<Database::Migrator::Core> for more documentation.
 =head1 ATTRIBUTES
 
 This class adds several attributes in addition to those implemented by
-L<Database::Migrator::Core>:
+L<Database::Migrator::Core>. All of these attributes are optional.
 
 =over 4
 
 =item * encoding
 
 The encoding of the database. This is only used when creating a new
-database. This is optional.
+database.
+
+=item * locale
+
+The locale of the database. This is only used when creating a new
+database.
+
+=item * lc_collate
+
+The LC_COLLATE setting for the database. This is only used when creating a new
+database.
+
+=item * lc_ctype
+
+The LC_CTYPE setting for the database. This is only used when creating a new
+database.
 
 =item * owner
 
 The owner of the database. This is only used when creating a new
-database. This is optional.
+database.
+
+=item * tablespace
+
+The tablespace for the database. This is only used when creating a new
+database.
+
+=item * template
+
+The template for the database. This is only used when creating a new database.
 
 =back
 
+=head1 SUPPORT
+
+Please submit bugs to the CPAN RT system at
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Database-Migrator-Pg or via email at
+bug-database-migrator-pg@rt.cpan.org.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by MaxMind, Inc..
+This software is Copyright (c) 2015 by MaxMind, Inc..
 
 This is free software, licensed under:
 
